@@ -32,7 +32,7 @@ pd.set_option('display.max_rows', 100)
 ## COMMAND LINE INTERFACE
 
 @click.group(invoke_without_command=True)
-@click.version_option("78.0.2", package_name="alacorder")
+@click.version_option("78.0.5", package_name="alacorder")
 @click.pass_context
 def cli(ctx):
     """
@@ -54,7 +54,7 @@ def cli(ctx):
             [sg.Text("Alacourt.com Credentials", font="Default 14")],
             [sg.Text("Customer ID: "), sg.Input(key="SQ-CUSTOMERID-")],
             [sg.Text("User ID: "), sg.Input(key="SQ-USERID-")],
-            [sg.Text("Password: "), sg.InputText(key="SQ-PASSWORD-",password_char='*', do_not_clear=False)],
+            [sg.Text("Password: "), sg.InputText(key="SQ-PASSWORD-",password_char='*')],
             [sg.Text("Max queries: "), sg.Input(key="SQ-MAX-", default_text="0", size=[5,1]),sg.Text("Skip from top: "), sg.Input(key="SQ-SKIP-", default_text="0",size=[5,1]),sg.Text("Speed Multiplier: "), sg.Input(key="SQ-SPEED-", default_text="1",size=[5,1])],
             [sg.Button("Start Query",key="SQ")]] # "SQ"
         archive_layout = [
@@ -99,7 +99,7 @@ def cli(ctx):
      / ___ |/ / /_/ / /__/ /_/ / /  / /_/ /  __/ /    
     /_/  |_/_/\__,_/\___/\____/_/   \__,_/\___/_/     
 
-    ALACORDER beta 78.0.2\n
+    ALACORDER beta 78.0.5\n
     Alacorder retrieves and processes case detail PDFs\ninto data tables suitable for research purposes.""",font="Courier", pad=(10,10))],
             [sg.Text("""1.  fetch - Retrieve case detail PDFs in bulk from Alacourt.com\n2.  archive - Create full text archives from PDF directory\n3.  table - Export data tables from case archive or directory\n4.  append - Append contents of one archive to another\n5.  mark - Mark already collected cases on query template
             """, font="Courier 12", size=[65,None])],
@@ -143,7 +143,6 @@ def cli(ctx):
                 a = alac.setinit(window['MA-INPUTPATH-'].get(),window['MA-OUTPUTPATH-'].get(),count=int(window['MA-COUNT-'].get()),archive=True,overwrite=window['MA-OVERWRITE-'].get(), append=window['MA-APPEND-'].get(), no_prompt=True,log=False)
             if event == "SQ":
                 pwd = window["SQ-PASSWORD-"].get()
-                window["SQ-PASSWORD-"].update("")
                 a = alac.fetch(window['SQ-INPUTPATH-'].get(),window['SQ-OUTPUTPATH-'].get(),cID=window['SQ-CUSTOMERID-'].get(),uID=window['SQ-USERID-'].get(),pwd=pwd,qmax=int(window['SQ-MAX-'].get()),speed=int(window['SQ-SPEED-'].get()),qskip=int(window['SQ-SKIP-'].get()))
             if event == "MQ":
                 a = alac.mark(window['MQ-INPUTPATH-'].get(),window['MQ-OUTPUTPATH-'].get())
